==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/usrstng_license.php <==
<?php
//==============================================================
// Program Name     : usrstng_license.php
// File Name        : 
//--------------------------------------------------------------
// Date             : 2002/01/15
// Author           : 
//--------------------------------------------------------------
// Note             : 饤Ͽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");
require("common_login.php");		// 
require("common_menu_change.inc");	// ˥塼
require("common_check.inc");		// 

require("usrstng_common.inc");		// 

define("TBL_CHK", "common_tblcheck");					// 桼ơ֥åơ֥̾
define("CSS_FILE", $JJ_CSS_ROOT . $JJ_CSS_NAME);		// 륷ȥե
define("TABLE_WIDTH", 600);								// ơ֥
define("SPACE_GIF_FILE", $JJ_IMG_ROOT . "spacer.gif");	// 


//==============================================================
// Function Name    : Create_LicenseTable
//--------------------------------------------------------------
// Note		        : 
//                  : 
//==============================================================
Function Create_LicenseTable()
{
	global $JJ_USE_DATABASE;
	// ǡ١³
	$db = new DB_Test;
	switch ($JJ_USE_DATABASE)
	{
		case "mysql":
		case "postgres":
		case "sqlserver":
			$str = "CREATE TABLE common_license (license varchar(32))";
			break;
		case "oracle8":
			$str = "CREATE TABLE common_license (license varchar2(32))";
			break;
		case "jet":
			$str = "CREATE TABLE common_license (license text(32))";
			break;
	}
	$db->query($str);

	$str = "insert into " . TBL_CHK . " values ('common_license')";
	$db->query($str);
	$db->Close();
}


//==============================================================
// Function Name    : regist
//--------------------------------------------------------------
// Note		        : 
//                  : 
//==============================================================
function regist()
{
	global $regist_code;

	$db = new DB_Test;
	
/***
	$query = sprintf("select * from %s where table_name='common_license'", TBL_CHK);
	$db->query($query);
	if ($db->nf() <= 0)
	{
		Create_LicenseTable();
	}
***/
	$query = sprintf("select * from common_license");
	$db->query($query);
	if ($db->nf() > 0)
	{
		if (!tchk($regist_code))
			$query = sprintf("UPDATE common_license SET license = '%s'", trim($regist_code));
	}
	else
	{
		if (tchk($regist_code))
			$regist_code .= "_" . strtoupper(strrev(dechex(time())));
		$query = sprintf("insert into  common_license values ('%s')", trim($regist_code));
	}
	$db->query($query);
	$db->close();
}


//==============================================================
// Function Name    : 
//--------------------------------------------------------------
// Note             : 
//                  : 
//==============================================================
function print_index()
{
	global $regist_code;

	// 
	print("<TABLE border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\"><TR><TD>\n");
	Print_modoru();
	print("</td></tr></table>\n");

	printf("<form action=\"%s\" method=\"post\">\n", PG_NAME());
	print("<input type=\"hidden\" name=\"action\" value=\"regist\">\n");

	print("<TABLE border=\"0\" cellpadding=\"5\" cellspacing=\"0\" class=\"color02\" width=\"400\">\n");
	print("<TR>\n");
	print("<TD colspan=\"2\">\n");
	$ujc = get_uruudoshi($regist_code);
	if ($ujc < 0) $ujc="̵";
	printf("ߤΥ饤󥹿 [%s] Ǥ\n", $ujc);
	print("</td></tr>\n");
	print("<TR>\n");
	print("<br><TD align=\"center\">饤󥹥</td>\n");
	print("<td align=\"center\">\n");
	printf("<INPUT size=\"30\" type=\"text\" name=\"regist_code\" value=\"%s\"></td>\n", substr($regist_code, 0, 16));
	print("</TR>\n");
	print("<TR>\n");
	print("<TD colspan=\"2\" align=\"center\">\n");
	printf("<INPUT type=\"submit\" value=\"Ͽ\"></TD>\n");
	print("</TR></TABLE>\n");
	print("</form>\n");

}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note             : 
//                  : 
//==============================================================

	// HTMLإåɽ
	include("common_printheader.inc");

	if ($JJ_PERMISSION != "admin")
		Error("ΥڡɽˤϴԸ¤ɬפǤ");

	if (!isset($action)) $action = "";
	switch ($action)
	{
		case "regist":
			regist();
			break;
		default:
			break;
	}

	$regist_code = get_license();

	printf("<TABLE border=\"0\" width=\"%d\" cellpadding=\"5\" cellspacing=\"0\">\n", TABLE_WIDTH);

	// ȥʬɽ
	print("<tr bgcolor=\"#cccccc\">\n");
	print("<td align=\"center\" class=\"color00\" width=\"50%\"><b>饤Ͽ</b></td>\n");
	print("<td width=\"50%\">&nbsp;</td>\n");
	print("</tr>\n");
	print("<tr class=\"color00\">\n");
	printf("<td colspan=\"2\"><img src=\"%s\"></td>\n", SPACE_GIF_FILE);
	print("</tr>\n");


	print("<TR><TD ALIGN=\"center\" bgcolor=\"white\" colspan=\"2\">\n");

	print_index();

	print("</TD></TR></TABLE>\n");

	// HTMLեåɽ
	include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/usrstng_license.php <==
<?php
//==============================================================
// Program Name     : usrstng_license.php
// File Name        : 
//--------------------------------------------------------------
// Date             : 2002/01/15
// Author           : 
//--------------------------------------------------------------
// Note             : 饤Ͽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");
require("common_login.php");		// 
require("common_menu_change.inc");	// ˥塼
require("common_check.inc");		// 

require("usrstng_common.inc");		// 

define("TBL_CHK", "common_tblcheck");					// 桼ơ֥åơ֥̾
define("CSS_FILE", $JJ_CSS_ROOT . $JJ_CSS_NAME);		// 륷ȥե
define("TABLE_WIDTH", 600);								// ơ֥
define("SPACE_GIF_FILE", $JJ_IMG_ROOT . "spacer.gif");	// 


//==============================================================
// Function Name    : Create_LicenseTable
//--------------------------------------------------------------
// Note		        : 
//                  : 
//==============================================================
Function Create_LicenseTable()
{
	global $JJ_USE_DATABASE;
	// ǡ١³
	$db = new DB_Test;
	switch ($JJ_USE_DATABASE)
	{
		case "mysql":
		case "postgres":
		case "sqlserver":
			$str = "CREATE TABLE common_license (license varchar(32))";
			break;
		case "oracle8":
			$str = "CREATE TABLE common_license (license varchar2(32))";
			break;
		case "jet":
			$str = "CREATE TABLE common_license (license text(32))";
			break;
	}
	$db->query($str);

	$str = "insert into " . TBL_CHK . " values ('common_license')";
	$db->query($str);
	$db->Close();
}


//==============================================================
// Function Name    : regist
//--------------------------------------------------------------
// Note		        : 
//                  : 
//==============================================================
function regist()
{
	global $regist_code;

	$db = new DB_Test;
	
/***
	$query = sprintf("select * from %s where table_name='common_license'", TBL_CHK);
	$db->query($query);
	if ($db->nf() <= 0)
	{
		Create_LicenseTable();
	}
***/
	$query = sprintf("select * from common_license");
	$db->query($query);
	if ($db->nf() > 0)
	{
		if (!tchk($regist_code))
			$query = sprintf("UPDATE common_license SET license = '%s'", trim($regist_code));
	}
	else
	{
		if (tchk($regist_code))
			$regist_code .= "_" . strtoupper(strrev(dechex(time())));
		$query = sprintf("insert into  common_license values ('%s')", trim($regist_code));
	}
	$db->query($query);
	$db->close();
}


//==============================================================
// Function Name    : 
//--------------------------------------------------------------
// Note             : 
//                  : 
//==============================================================
function print_index()
{
	global $regist_code;

	// 
	print("<TABLE border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\"><TR><TD>\n");
	Print_modoru();
	print("</td></tr></table>\n");

	printf("<form action=\"%s\" method=\"post\">\n", PG_NAME());
	print("<input type=\"hidden\" name=\"action\" value=\"regist\">\n");

	print("<TABLE border=\"0\" cellpadding=\"5\" cellspacing=\"0\" class=\"color02\" width=\"400\">\n");
	print("<TR>\n");
	print("<TD colspan=\"2\">\n");
	$ujc = get_uruudoshi($regist_code);
	if ($ujc < 0) $ujc="̵";
	printf("ߤΥ饤󥹿 [%s] Ǥ\n", $ujc);
	print("</td></tr>\n");
	print("<TR>\n");
	print("<br><TD align=\"center\">饤󥹥</td>\n");
	print("<td align=\"center\">\n");
	printf("<INPUT size=\"30\" type=\"text\" name=\"regist_code\" value=\"%s\"></td>\n", substr($regist_code, 0, 16));
	print("</TR>\n");
	print("<TR>\n");
	print("<TD colspan=\"2\" align=\"center\">\n");
	printf("<INPUT type=\"submit\" value=\"Ͽ\"></TD>\n");
	print("</TR></TABLE>\n");
	print("</form>\n");

}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note             : 
//                  : 
//==============================================================

	// HTMLإåɽ
	include("common_printheader.inc");

	if ($JJ_PERMISSION != "admin")
		Error("ΥڡɽˤϴԸ¤ɬפǤ");

	if (!isset($action)) $action = "";
	switch ($action)
	{
		case "regist":
			regist();
			break;
		default:
			break;
	}

	$regist_code = get_license();

	printf("<TABLE border=\"0\" width=\"%d\" cellpadding=\"5\" cellspacing=\"0\">\n", TABLE_WIDTH);

	// ȥʬɽ
	print("<tr bgcolor=\"#cccccc\">\n");
	print("<td align=\"center\" class=\"color00\" width=\"50%\"><b>饤Ͽ</b></td>\n");
	print("<td width=\"50%\">&nbsp;</td>\n");
	print("</tr>\n");
	print("<tr class=\"color00\">\n");
	printf("<td colspan=\"2\"><img src=\"%s\"></td>\n", SPACE_GIF_FILE);
	print("</tr>\n");


	print("<TR><TD ALIGN=\"center\" bgcolor=\"white\" colspan=\"2\">\n");

	print_index();

	print("</TD></TR></TABLE>\n");

	// HTMLեåɽ
	include("common_printfooter.inc");

?>
